fn derive_key(
kdf: &EnvelopeKdf,
password: &str,
) -> Result<[u8; 32], PasswordProtectedKeyEnvelopeError>Expand description
Derives the envelope key from the password using the configured KDF.
fn derive_key(
kdf: &EnvelopeKdf,
password: &str,
) -> Result<[u8; 32], PasswordProtectedKeyEnvelopeError>Derives the envelope key from the password using the configured KDF.